@@ -1,8 +1,24 @@
+# (C) Copyright 2018, 2020-2021 by Rocky Bernstein
+#
+#  This program is free software; you can redistribute it and/or
+#  modify it under the terms of the GNU General Public License
+#  as published by the Free Software Foundation; either version 2
+#  of the License, or (at your option) any later version.
+#
+#  This program is distributed in the hope that it will be useful,
+#  but WITHOUT ANY WARRANTY; without even the implied warranty of
+#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+#  GNU General Public License for more details.
+#
+#  You should have received a copy of the GNU General Public License
+#  along with this program; if not, write to the Free Software
+#  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
+
 """Python disassembly functions specific to wordcode from Python 3.6+
 """
-from xdis import PYTHON3
 from xdis.bytecode import op_has_argument
 
+
 def unpack_opargs_wordcode(code, opc):
     extended_arg = 0
     try:
@@ -16,7 +32,7 @@ def unpack_opargs_wordcode(code, opc):
         for i in range(0, n, 2):
             op = ord(code[i])
             if op_has_argument(op, opc):
-                arg = ord(code[i+1]) | extended_arg
+                arg = ord(code[i + 1]) | extended_arg
                 extended_arg = (arg << 8) if op == opc.EXTENDED_ARG else 0
             else:
                 arg = None
@@ -25,62 +41,32 @@ def unpack_opargs_wordcode(code, opc):
         for i in range(0, n, 2):
             op = code[i]
             if op_has_argument(op, opc):
-                arg = code[i+1] | extended_arg
+                arg = code[i + 1] | extended_arg
                 extended_arg = (arg << 8) if op == opc.EXTENDED_ARG else 0
             else:
                 arg = None
             yield (i, op, arg)
 
 
-def findlinestarts(code, dup_lines=False):
-    """Find the offsets in a byte code which are start of lines in the source.
-
-    Generate pairs (offset, lineno) as described in Python/compile.c.
-
-    """
-    if PYTHON3:
-        byte_increments = code.co_lnotab[0::2]
-        line_increments = code.co_lnotab[1::2]
-    else:
-        byte_increments = [ord(c) for c in code.co_lnotab[0::2]]
-        line_increments = [ord(c) for c in code.co_lnotab[1::2]]
-
-    lastlineno = None
-    lineno = code.co_firstlineno
-    addr = 0
-    for byte_incr, line_incr in zip(byte_increments, line_increments):
-        if byte_incr:
-            if (lineno != lastlineno or
-                (not dup_lines and 0 < byte_incr < 255)):
-                yield (addr, lineno)
-                lastlineno = lineno
-            addr += byte_incr
-        if line_incr >= 0x80:
-            # line_increments is an array of 8-bit signed integers
-            line_incr -= 0x100
-        lineno += line_incr
-    if (lineno != lastlineno or
-        (not dup_lines and 0 < byte_incr < 255)):
-        yield (addr, lineno)
-
-
-def get_jump_targets(code, opc):
+def findlabels(code, opc):
     """Returns a list of instruction offsets in the supplied bytecode
     which are the targets of some sort of jump instruction.
     """
     offsets = []
     for offset, op, arg in unpack_opargs_wordcode(code, opc):
         if arg is not None:
+            arg2 = arg * 2 if opc.version_tuple >= (3, 10) else arg
             if op in opc.JREL_OPS:
-                jump_offset = offset + 2 + arg
+                jump_offset = offset + 2 + arg2
             elif op in opc.JABS_OPS:
-                jump_offset = arg
+                jump_offset = arg2
             else:
                 continue
             if jump_offset not in offsets:
                 offsets.append(jump_offset)
     return offsets
 
+
 def get_jump_target_maps(code, opc):
     """Returns a dictionary where the key is an offset and the values are
     a list of instruction offsets which can get run before that
@@ -110,6 +96,3 @@ def get_jump_target_maps(code, opc):
                 prev_list.append(offset)
                 offset2prev[jump_offset] = prev_list
     return offset2prev
-
-
-findlabels = get_jump_targets
